package javax.xml.crypto.dsig.dom;

import javax.xml.crypto.KeySelector;
import java.security.Key;
import org.w3c.dom.Node;
import javax.xml.crypto.dsig.XMLSignContext;
import javax.xml.crypto.dom.DOMCryptoContext;

public class DOMSignContext extends DOMCryptoContext implements XMLSignContext
{
    private Node parent;
    private Node nextSibling;
    
    public DOMSignContext(Key key, Node parent) {
        if (key == null) {
            throw new NullPointerException("signingKey cannot be null");
        }
        if (parent == null) {
            throw new NullPointerException("parent cannot be null");
        }
        this.setKeySelector(KeySelector.singletonKeySelector(key));
        this.parent = parent;
        return;
    }
    
    public DOMSignContext(Key key, Node parent, Node nextSibling) {
        if (key == null) {
            throw new NullPointerException("signingKey cannot be null");
        }
        if (parent == null) {
            throw new NullPointerException("parent cannot be null");
        }
        if (nextSibling == null) {
            throw new NullPointerException("nextSibling cannot be null");
        }
        this.setKeySelector(KeySelector.singletonKeySelector(key));
        this.parent = parent;
        this.nextSibling = nextSibling;
        return;
    }
    
    public DOMSignContext(KeySelector keySelector, Node parent) {
        if (keySelector == null) {
            throw new NullPointerException("key selector cannot be null");
        }
        if (parent == null) {
            throw new NullPointerException("parent cannot be null");
        }
        this.setKeySelector(keySelector);
        this.parent = parent;
        return;
    }
    
    public DOMSignContext(KeySelector keySelector, Node parent, Node nextSibling) {
        if (keySelector == null) {
            throw new NullPointerException("key selector cannot be null");
        }
        if (parent == null) {
            throw new NullPointerException("parent cannot be null");
        }
        if (nextSibling == null) {
            throw new NullPointerException("nextSibling cannot be null");
        }
        this.setKeySelector(keySelector);
        this.parent = parent;
        this.nextSibling = nextSibling;
        return;
    }
    
    public void setParent(Node parent) {
        if (parent == null) {
            throw new NullPointerException("parent is null");
        }
        this.parent = parent;
        return;
    }
    
    public void setNextSibling(Node nextSibling) {
        this.nextSibling = nextSibling;
    }
    
    public Node getParent() {
        return this.parent;
    }
    
    public Node getNextSibling() {
        return this.nextSibling;
    }
}
